'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// Android Studio theme colors
const base00 = '#282b2e', // Background
base01 = '#a9b7c6', // Foreground
base02 = '#4e5254', // Selection
base03 = '#7f85891f', // Line highlight
base04 = '#00FF00', // Caret
base05 = '#cc7832', // Keyword, Deleted, ClassName
base06 = '#6897bb', // Number, Literal, DerefOperator
base07 = '#629755', // Link, VariableName
base08 = 'grey', // Comment, Quote
base09 = '#bbb529', // Meta, DocumentMeta
base0A = '#6a8759', // String, PropertyName, AttributeValue
base0B = '#ffc66d', // Heading, TypeName
base0C = '#a9b7c6'; // AttributeName
// Define the editor theme styles for Android Studio.
const androidStudioTheme = view.EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: base00,
    },
    '.cm-content': {
        caretColor: base04,
    },
    '&.cm-focused .cm-cursor': {
        borderLeftColor: base04,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: base02,
    },
    '.cm-activeLine': {
        backgroundColor: base03,
    },
    '.cm-gutters': {
        backgroundColor: base00,
        color: base01,
    },
    '.cm-tooltip': {
        backgroundColor: base01,
    },
}, { dark: true });
// Define the highlighting style for code in the Android Studio theme.
const androidStudioHighlightStyle = language.HighlightStyle.define([
    { tag: [highlight.tags.keyword, highlight.tags.deleted, highlight.tags.className], color: base05 },
    { tag: [highlight.tags.number, highlight.tags.literal, highlight.tags.derefOperator], color: base06 },
    { tag: [highlight.tags.link, highlight.tags.variableName], color: base07 },
    { tag: [highlight.tags.comment, highlight.tags.quote], color: base08 },
    { tag: [highlight.tags.meta, highlight.tags.documentMeta], color: base09 },
    { tag: [highlight.tags.string, highlight.tags.propertyName, highlight.tags.attributeValue], color: base0A },
    { tag: [highlight.tags.heading, highlight.tags.typeName], color: base0B },
    { tag: [highlight.tags.attributeName], color: base0C },
    { tag: highlight.tags.emphasis, fontStyle: 'italic' },
]);
// Extension to enable the Android Studio theme (both the editor theme and the highlight style).
const androidStudio = [
    androidStudioTheme,
    language.syntaxHighlighting(androidStudioHighlightStyle),
];

exports.androidStudio = androidStudio;
exports.androidStudioHighlightStyle = androidStudioHighlightStyle;
exports.androidStudioTheme = androidStudioTheme;
